@@ -1,21 +1,21 @@
 // -*- c++ -*-
 #ifndef _GLIBMM_VALUE_H
 #define _GLIBMM_VALUE_H
-/* $Id: value.h,v 1.8 2005/01/21 19:26:04 murrayc Exp $ */
+/* $Id: value.h 779 2009-01-19 17:58:50Z murrayc $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -69,9 +69,21 @@ public:
    *
    * init() is not implemented as constructor, to avoid the necessity
    * to implement a forward constructor in each derived class.
+   *
+   * @param type The type that the Value should hold.
    */
   void init(GType type);
 
+  /** Setup the GValue storing the type and value of the specified @a value.
+   * Note that init() should never be called twice.
+   *
+   * init() is not implemented as constructor, to avoid the necessity
+   * to implement a forward constructor in each derived class.
+   *
+   * @param value The existing GValue.
+   */
+  void init(const GValue* value);
+
   /** Reset contents to the default value of its type.
    */
   void reset();
